@@ -73,10 +73,11 @@ var webbox = {
             if(found > 0 && service.added !== true)
                 service.commit();
 
+
             // Grid Current Power Chart
             if(d['GriPwr'].value !== null) {
-                var id = 'smawebbox_' + service.name + '.current';
-                var chart = webbox.charts[id];
+                const id = 'smawebbox_' + service.name + '.current';
+                let chart = webbox.charts[id];
 
                 if(typeof chart === 'undefined') {
                     chart = {
@@ -111,8 +112,8 @@ var webbox = {
             }
 
             if(d['GriEgyTdy'].value !== null) {
-                var id = 'smawebbox_' + service.name + '.today';
-                var chart = webbox.charts[id];
+                const id = 'smawebbox_' + service.name + '.today';
+                let chart = webbox.charts[id];
 
                 if(typeof chart === 'undefined') {
                     chart = {
@@ -147,8 +148,8 @@ var webbox = {
             }
 
             if(d['GriEgyTot'].value !== null) {
-                var id = 'smawebbox_' + service.name + '.total';
-                var chart = webbox.charts[id];
+                const id = 'smawebbox_' + service.name + '.total';
+                let chart = webbox.charts[id];
 
                 if(typeof chart === 'undefined') {
                     chart = {
@@ -225,7 +226,7 @@ var webbox = {
     },
 
     // module.update()
-    // this is called repeatidly to collect data, by calling
+    // this is called repeatedly to collect data, by calling
     // netdata.serviceExecute()
     update: function(service, callback) {
         service.execute(function(serv, data) {
